Shtick: Stick

Description Methods Methods Note

Description

Shticky stuff, euwww

Methods

Methods

Public methods


Method new()

Usage
Shtick$new(id)
Arguments
id

CSS id of element to make shticky.

Details

Initialize Shticky


Method shtick()

Usage
Shtick$shtick(left = NULL, right = NULL, top = NULL, bottom = NULL)
Arguments
left, right, top, bottom

Corresponds to CSS, if an integer it is treated as pixels, if a string is used as-is.

Details

Sticks the element.


Method unshtick()

Usage
Shtick$unshtick()
Details

Unsticks the element.


Method clone()

The objects of this class are cloneable with this method.

Usage
Shtick$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

Note

selector is a valid CSS selector i.e.: #id or .class.


JohnCoene/shticky documentation built on Jan. 31, 2020, 12:23 a.m.