Description Methods Methods Note
Shticky stuff, euwww
new: Creates a shticky element, takes a selector.
shtick: Make the element shticky.
unshtick: Unshticks the element.
new()Shtick$new(id)
idCSS id of element to make shticky.
Initialize Shticky
shtick()Shtick$shtick(left = NULL, right = NULL, top = NULL, bottom = NULL)
left, right, top, bottomCorresponds to CSS, if an integer it is treated as pixels, if a string is used as-is.
Sticks the element.
unshtick()Shtick$unshtick()
Unsticks the element.
clone()The objects of this class are cloneable with this method.
Shtick$clone(deep = FALSE)
deepWhether to make a deep clone.
selector is a valid CSS selector i.e.: #id or .class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.